Index: test/plugin/DetachedInitializationTest.cpp |
=================================================================== |
--- a/test/plugin/DetachedInitializationTest.cpp |
+++ b/test/plugin/DetachedInitializationTest.cpp |
@@ -34,16 +34,16 @@ |
* The destructor has to be able to block to wait for the initializer |
* This test ensures that it doesn't block unnecessarily. |
*/ |
-TEST(DetachedInitializer, DestructorDoesNotBlockAfterNoActivity) |
+TEST(DetachedInitializerStaticFunction, DestructorDoesNotBlockAfterNoActivity) |
{ |
- DetachedInitializer<NullFunction> x; |
+ DetachedInitializerStaticFunction<NullFunction> x; |
} |
-TEST(DetachedInitializer, NullInstance) |
+TEST(DetachedInitializerStaticFunction, NullInstance) |
{ |
ASSERT_NO_THROW( |
{ |
- DetachedInitializer<NullFunction> x; |
+ DetachedInitializerStaticFunction<NullFunction> x; |
x.SpawnInitializer(); |
x.EnsureInitialized(); |
} |
@@ -60,9 +60,9 @@ |
* It's disabled in the present code base so it doesn't break the unit test. |
* Check this test again when we upgrade past GTest 1.60 and the VS 2012 toolset. |
*/ |
-TEST(DetachedInitializer, DISABLED_EnsureInitializedThrowingGtestDefectIllustration) |
+TEST(DetachedInitializerStaticFunction, DISABLED_EnsureInitializedThrowingGtestDefectIllustration) |
{ |
- DetachedInitializer<FailFunction> x; |
+ DetachedInitializerStaticFunction<FailFunction> x; |
bool threw = false; |
try |
{ |
@@ -80,9 +80,9 @@ |
* This test fails because of a defect in Google Test. |
* It's disabled at present, but should be enabled when the previous test is working. |
*/ |
-TEST(DetachedInitializer, DISABLED_EnsureInitializedThrowing) |
+TEST(DetachedInitializerStaticFunction, DISABLED_EnsureInitializedThrowing) |
{ |
- DetachedInitializer<FailFunction> x; |
+ DetachedInitializerStaticFunction<FailFunction> x; |
try |
{ |
x.SpawnInitializer(); |
@@ -104,11 +104,11 @@ |
} |
/* |
* Resetable version of DetachedInitializer |
*/ |
template<void(&F)()> |
-class DidReset |
- : public DetachedInitializer<F> |
+class DisfReset |
+ : public DetachedInitializerStaticFunction<F> |
{ |
public: |
void Reset() |
@@ -124,7 +124,7 @@ |
}; |
/* |
* Uses designated implementation pattern of DetachedInitializer |
*/ |
struct DeferredIncrementingInitializer |
{ |
@@ -135,7 +135,7 @@ |
++initializedCount; |
} |
- typedef DidReset<Incrementer> InitializerType; |
+ typedef DisfReset<Incrementer> InitializerType; |
static InitializerType di; |
public: |
@@ -104,11 +104,11 @@ |
} |
/* |
- * Resetable version of DetachedInitializer |
+ * Resetable version of DetachedInitializerStaticFunction |
*/ |
template<void(&F)()> |
@@ -124,7 +124,7 @@ |
}; |
/* |
- * Uses designated implementation pattern of DetachedInitializer |
+ * Uses designated implementation pattern of DetachedInitializerStaticFunction |
*/ |
struct DeferredIncrementingInitializer |